@@ -17,7 +17,7 @@ from energinetml.cli.utils import discover_model
               default=False, is_flag=True,
               help='Run training in cloud mode (do not use locally)')
 @click.option('--force-download', '-f', 'force_download',
-              default=True, is_flag=True,
+              default=False, is_flag=True,
               help='Force download of datasets (ignore locally cached files)')
 @click.option('--seed', '-s',
               required=False, default=None, type=str,
@@ -34,20 +34,6 @@ def train(parameters, cloud_mode, force_download, seed, model):
     :param energinetml.Model model:
     """
 
-    # -- Train Parameters ----------------------------------------------------
-
-    params = model.parameters.copy()
-    params.update(dict(param.split(':') for param in parameters))
-    params['seed'] = seed \
-        if seed is not None \
-        else model.generate_seed()
-
-    # -- Tags ----------------------------------------------------------------
-
-    tags = model.default_tags.copy()
-    tags[PACKAGE_NAME] = str(PACKAGE_VERSION)
-    tags.update(params)
-
     # -- Training context ----------------------------------------------------
 
     if cloud_mode:
@@ -57,6 +43,22 @@ def train(parameters, cloud_mode, force_download, seed, model):
         # Training is running locally
         context = backend.get_local_training_context(force_download)
 
+    # -- Train Parameters ----------------------------------------------------
+
+    params = {}
+    params.update(context.get_parameters(model))
+    params.update(dict(param.split(':') for param in parameters))
+    params['seed'] = seed \
+        if seed is not None \
+        else model.generate_seed()
+
+    # -- Tags ----------------------------------------------------------------
+
+    tags = {PACKAGE_NAME: str(PACKAGE_VERSION)}
+    tags.update(params)
+    tags.update(context.get_tags(model))
+    tags.update(model.extra_tags())
+
     # -- Training ------------------------------------------------------------
 
     click.echo('Training model...')
@@ -94,7 +96,8 @@ def train(parameters, cloud_mode, force_download, seed, model):
         trained_model.verify()
     except trained_model.Invalid as e:
         click.echo('-' * 79)
-        click.echo('%s is INVALID: %s' % (trained_model.__class__.__name__, str(e)))
+        click.echo('%s does not validate: %s' % (
+            trained_model.__class__.__name__, str(e)))
         raise click.Abort()
 
     # -- Dump output to disk -------------------------------------------------
